darkhistory.spec.spectools.get_bin_bound — DarkHistory documentation

# darkhistory.spec.spectools.get_bin_bound

`darkhistory.spec.spectools.` `get_bin_bound`(eng)

  Returns the bin boundary of an abscissa.

  The bin boundaries are computed by taking the midpoint of the log of the abscissa. The first and last entries are computed by taking all of the bins to be symmetric with respect to the bin center.

  Parameters: | eng : ndarray Abscissa from which the bin boundary is obtained.
  Returns: | ndarray The bin boundaries.

#### Previous topic

darkhistory.spec.spectools.engloss_rebin_fast

#### Next topic

darkhistory.spec.spectools.get_bounds_between

### This Page

Show Source